import os
from shutil import copy2
import xml.etree.ElementTree as ET
import logging

### Einstellungen aus Settings.xml Datei einlesen
tree = ET.parse("Settings.xml")
settings = tree.getroot()

### Einfaches logging mit logging Modul
logging.basicConfig(filename="LogFileName.log", level=logging.getLevelName(settings.find("LoggingLevel").text), format="%(asctime)s; %(levelname)s; %(message)s")
logging.info("Dateien kopieren gestartet.")

try:
    quellOrdner = settings.find("QuellOrdner").text
    zielOrdner = settings.find("ZielOrdner").text

    # Schleife über alle Dateien in einem Ordner und allen Unterordnern
    for pfad, unterverzeichnisse, dateien in os.walk(quellOrdner):
        for datei in dateien:
            # Pfad und Dateinamen kombinieren
            quelle = os.path.join(pfad, datei)
            ziel = quelle.replace(quellOrdner, zielOrdner)

            # Zielverzeichnis erstellen falls es noch nicht existiert
            if not os.path.exists(os.path.dirname(ziel)):
                os.makedirs(os.path.dirname(ziel))
            
            # Datei kopieren
            logging.debug(f"Quelle: {quelle} --> Ziel: {ziel}")
            copy2(quelle, ziel)

    logging.info("Dateien kopieren abgeschlossen.")

except Exception as ex:
    logging.exception(f"EXCEPTION: {ex}")
    print("Es ist eine Exception aufgetreten, das Programm wird jetzt beendet.")
