import datetime
import statistics
import openpyxl
import xml.etree.ElementTree as ET
import logging


### Einstellungen aus Settings.xml Datei einlesen
tree = ET.parse("Settings.xml")
settings = tree.getroot()

### Einfaches logging mit logging Modul
logging.basicConfig(filename="LogFileName.log", level=logging.getLevelName(settings.find("LoggingLevel").text), format="%(asctime)s; %(levelname)s; %(message)s")
logging.debug("Debug logging ...")
logging.info("Prozessdaten Auswetung gestartet.")
logging.warning("Warnung logging ...")
logging.error("Error logging ....")
logging.critical("Kritisches logging ...")

### Zeitraum einlesen
zeitraumStart = settings.find("ZeitraumStart").text
zeitraumEnde = settings.find("ZeitraumEnde").text
if zeitraumStart == "" or zeitraumEnde == "":
    zeitraumStart = datetime.datetime.today().replace(hour=0, minute=0, second=0, microsecond=0) - datetime.timedelta(days=1)
    zeitraumEnde = datetime.datetime.today().replace(hour=0, minute=0, second=0, microsecond=0)
else:
    zeitraumStart = datetime.datetime.strptime(zeitraumStart, "%Y-%m-%d %H:%M:%S")
    zeitraumEnde = datetime.datetime.strptime(zeitraumEnde, "%Y-%m-%d %H:%M:%S")

### Anlagendaten einlesen
zellen = []
# Log Datei öffnen
for zeile in open(r".\ZuProzessieren\AnlagenLogfile.log", "r").readlines():
    zelle = zeile.strip().split(";")
    zeitstempel = datetime.datetime.strptime(zelle[0], "%Y-%m-%d %H:%M:%S")
    # Solarzellen nach Zeit filtern
    if zeitstempel >= zeitraumStart and zeitstempel <= zeitraumEnde:
        zellen.append([zeitstempel, float(zelle[1]), zelle[2]])

### Daten verarbeiten
# neue Listen mit Leistungs Daten erstellen
leistungen = [zelle[1] for zelle in zellen]

# Kennzahlen auslesen
durchsatz = len(zellen)
minLeistung = min(leistungen)
maxLeistung = max(leistungen)
durchschnittlicheLeistung = statistics.mean(leistungen)
anzahlGutzellen = 0
anzahlSchlechtzellen = 0
for zelle in zellen:
    if zelle[2] == "A":
        anzahlGutzellen += 1
    else:
        anzahlSchlechtzellen += 1

# Leistungsverteilung
leistungsklassen = settings.find("Leistungsklassen").text.split(", ")
leistungsklassen = [float(leistungsklasse) for leistungsklasse in leistungsklassen]

leistungsverteilung = {}
for leistungsklasse in leistungsklassen:
    leistungsverteilung[leistungsklasse] = 0

for leistung in leistungen:
    for leistungsklasse in leistungsklassen:
        if leistung <= leistungsklasse:
            leistungsverteilung[leistungsklasse] += 1
            break

### Daten eintragen und speichern
# Excel Vorlage öffnen
excelWorkbook = openpyxl.load_workbook("Visualisierung.xlsx")
excelWorksheet = excelWorkbook["Anlage1"]

# eintragen
excelWorksheet.cell(row=4, column=2).value = zeitraumStart
excelWorksheet.cell(row=4, column=3).value = zeitraumEnde
excelWorksheet.cell(row=23, column=1).value = durchsatz
excelWorksheet.cell(row=23, column=2).value = anzahlGutzellen
excelWorksheet.cell(row=23, column=3).value = anzahlSchlechtzellen
excelWorksheet.cell(row=23, column=4).value = minLeistung
excelWorksheet.cell(row=23, column=5).value = maxLeistung
excelWorksheet.cell(row=23, column=6).value = durchschnittlicheLeistung

zeile = 26
for leistungsklasse, anzahl in leistungsverteilung.items():
    excelWorksheet.cell(row=zeile, column=2).value = anzahl
    zeile += 1

# speichern
excelWorkbook.save(f"{datetime.datetime.now().strftime('%Y%m%d_%H%M%S')}_Auswertung.xlsx")

logging.info("Prozessdaten Auswetung abgeschlossen =)")
